Group of rules related to sections.



# SEC-001: X-axis Visual Alignment

**Applies to:**

- [Section](/layout/section)

**Fix State:** Not Automatically Fixable

```
No visual should have its x-axis misaligned with other visuals in the
    same section by less than 10 pixel.
```

# SEC-002: Y-axis Visual Alignment

**Applies to:**

- [Section](/layout/section)

**Fix State:** Not Automatically Fixable

```
No visual should have its x-axis misaligned with other visuals in the
    same section by less than 10 pixel.
```

# SEC-003: Section Naming

**Applies to:**

- [Section](/layout/section)

**Fix State:** Not Automatically Fixable

```
Section names should be human readable. This means no underscores, capital case usage, and less than 35 characters (the max Power BI allows before using ellipses).
```
